@@ -10,13 +10,17 @@ from tubemap import *
 from tflapp_mainwindow import *
 import location
 
-CURRENTVERSION = "0.1.1"
+CURRENTVERSION = "0.1.2"
 
 
 PLANNER_URL_PART1 = "http://journeyplanner.tfl.gov.uk/user/XSLT_TRIP_REQUEST2?language=en&sessionID=0&requestID=0&ptOptionsActive=1&itOptionsActive=1&imparedOptionsActive=1&ptAdvancedOptions=1&advOptActive_2=1&advOpt_2=1&execInst=normal&command=&itdLPxx_request=&itdLPxx_view=&itdLPxx_tubeMap=&calculateDistance=1&name_origin="
 PLANNER_URL_PART2 = "&nameState_origin=notidentified&nameDefaultText_origin=start&place_origin=London&type_origin=locator&name_destination="
 PLANNER_URL_PART3 ="&nameState_destination=notidentified&nameDefaultText_destination=end&place_destination=London&type_destination=locator&itdTripDateTimeDepArr=dep&Submit=Search&routeType=LEASTTIME&name_via=Enter+location+(optional)&nameState_via=notidentified&nameDefaultText_via=Enter+location+(optional)&type_via=stop&place_via=London&placeDefaultText_via=London&includedMeans=checkbox&inclMOT_11=1&inclMOT_0=on&inclMOT_1=on&inclMOT_2=on&inclMOT_4=on&inclMOT_5=on&inclMOT_7=on&inclMOT_9=on&trITMOTvalue101=60&trITMOTvalue=20&trITMOT=100&changeSpeed=Fast"
 
+GOOG_TRANS_P1 = "http://maps.google.com/m/directions?dirflg=r&hl=en&saddr="
+GOOG_TRANS_P2 = "&daddr="
+GOOG_TRANS_P3 = "&dirflg=r"
+
 
 class TflAppMain(QtGui.QMainWindow):
     def __init__(self, parent=None):
@@ -73,24 +77,40 @@ class TflAppMain(QtGui.QMainWindow):
     def doGetmeHome(self):
         self.showBusyIndicator()
         currentLoc = self.getCurrentPCode()
+        self.progress.repaint()
+
+        #check if current position is within London. If so, check if the destination is within London
+        if( (51.286829 <= self.curLocLat <= 51.69232322) and (-0.510350 <= self.curLocLong <= 0.334030) ):
+            destInLondon = checkDestInLond(self.dest)
+
+        self.progress.destroy(True, True)
+
         if( currentLoc != ""):
           self.dest = self.ui.lineEditHomePC.text()
-          self.progress.setLabelText("Opening Journey Planner in external Browser")
+          #self.progress.setLabelText("Opening Journey Planner in external Browser")
           print "start: " + currentLoc +  "& dest:" + self.dest
-          finalUrl = PLANNER_URL_PART1 + currentLoc + PLANNER_URL_PART2 + self.dest + PLANNER_URL_PART3
+          #If current loc and dest are in london, use tfl; else use google transit
+          if( (51.286829 <= self.curLocLat <= 51.69232322) and (-0.510350 <= self.curLocLong <= 0.334030) and destInLondon ):
+              finalUrl = PLANNER_URL_PART1 + currentLoc + PLANNER_URL_PART2 + self.dest + PLANNER_URL_PART3
+          else:
+              os.system('dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Start or destination is outside London. Maybe the Google gods can help instead"')
+
+              finalUrl = GOOG_TRANS_P1 + currentLoc + GOOG_TRANS_P2 + self.dest + GOOG_TRANS_P3
+
           QtGui.QDesktopServices.openUrl(QtCore.QUrl(finalUrl, QtCore.QUrl.TolerantMode))
-        self.progress.destroy(True, True)
+
 
     def getCurrentPCode(self):
         self.progress.setLabelText("Getting approx location via cellID")
         self.getCurrentLoc()
         # check if recieved lat/long is within london's bounding box
         # from: http://isithackday.com/geoplanet-explorer/index.php?woeid=23416974
-        if( (51.286829 <= self.curLocLat <= 51.69232322) and (-0.510350 <= self.curLocLong <= 0.334030) ):
+        #if( (51.286829 <= self.curLocLat <= 51.69232322) and (-0.510350 <= self.curLocLong <= 0.334030) ):
+        if( (49.871159 <= self.curLocLat <= 55.811741) and (-6.379880 <= self.curLocLong <= 1.768960) ):
             self.progress.setLabelText("Geolocating postcode")
-            pCode = self.getCurrentPCodeFromLoc()
+            pCode = self.doPCodeLocConv()
         else:
-            infoText = "Sorry, but it appears that you're outside London. The tfl Journeyplanner only works when you're within London :("
+            infoText = "Sorry, but it appears that you're outside England. This app is not designed to work outside the UK\n This limitation may be removed at a later stage"
             QtGui.QMessageBox.information(self, "Whoops", infoText)
             pCode = ""
         
@@ -112,7 +132,7 @@ class TflAppMain(QtGui.QMainWindow):
         self.loop.run()
 
 
-    def getCurrentPCodeFromLoc(self):
+    def doPCodeLocConv(self):
         openConn = ConnMan()
         openConn.startConnMan()
 
@@ -124,6 +144,23 @@ class TflAppMain(QtGui.QMainWindow):
 
         return str(postcodeNode[0].firstChild.data)
 
+    def checkDestInLond(self, dest):
+        url = "http://www.uk-postcodes.com/postcode/" + dest + ".xml"
+
+        response = minidom.parse(urllib.urlopen(url))
+        latNode = response.getElementsByTagName('lat')
+        lngNode = response.getElementsByTagName('lng')
+
+        lat = float(latNode[0].firstChild.data)
+        lng = float(lngNode[0].firstChild.data)
+        if( (51.286829 <= lat <= 51.69232322) and (-0.510350 <= long <= 0.334030) ):
+            print "Destination is withn London"
+            return True
+        else:
+            print "Destination is outside London"
+            return False
+
+
     def showTubeMap(self):
         # Show busy indicator as the initial display seems to chug
         self.setAttribute(QtCore.Qt.WA_Maemo5ShowProgressIndicator )
@@ -132,7 +169,7 @@ class TflAppMain(QtGui.QMainWindow):
         self.setAttribute(QtCore.Qt.WA_Maemo5ShowProgressIndicator, False )
         return
 
-    #Note that this is only ever triggered if the user hits "return" ont eh keyboard
+    #Note that this is only ever triggered if the user hits "return" on the keyboard
     def saveHome(self):
         print "saving settings"
         self.settings.setValue("home_Pcode", self.ui.lineEditHomePC.text() )
